Index: webrtc/modules/audio_device/android/java/src/org/webrtc/voiceengine/WebRtcAudioManager.java |
diff --git a/webrtc/modules/audio_device/android/java/src/org/webrtc/voiceengine/WebRtcAudioManager.java b/webrtc/modules/audio_device/android/java/src/org/webrtc/voiceengine/WebRtcAudioManager.java |
index ab17eece1aa8f8ccc90e575133389707bd6449b0..d94839c8295d686a88700cfa9b36bf172ff2c647 100644 |
--- a/webrtc/modules/audio_device/android/java/src/org/webrtc/voiceengine/WebRtcAudioManager.java |
+++ b/webrtc/modules/audio_device/android/java/src/org/webrtc/voiceengine/WebRtcAudioManager.java |
@@ -83,11 +83,11 @@ public class WebRtcAudioManager { |
// Private utility class that periodically checks and logs the volume level |
// of the audio stream that is currently controlled by the volume control. |
// A timer triggers logs once every 10 seconds and the timer's associated |
// thread is named "WebRtcVolumeLevelLoggerThread". |
private static class VolumeLogger { |
private static final String THREAD_NAME = "WebRtcVolumeLevelLoggerThread"; |
- private static final int TIMER_PERIOD_IN_SECONDS = 10; |
+ private static final int TIMER_PERIOD_IN_SECONDS = 30; |
private final AudioManager audioManager; |
private Timer timer; |
@@ -83,11 +83,11 @@ public class WebRtcAudioManager { |
// Private utility class that periodically checks and logs the volume level |
// of the audio stream that is currently controlled by the volume control. |
- // A timer triggers logs once every 10 seconds and the timer's associated |
+ // A timer triggers logs once every 30 seconds and the timer's associated |
// thread is named "WebRtcVolumeLevelLoggerThread". |
private static class VolumeLogger { |